#!/usr/bin/env python
# -*- coding: utf-8 -*-

from .focalloss import FocalLoss
from .circleloss import CircleLoss  #, convert_label_to_similarity
from .label_smoothing import LabelSmoothingCrossEntropy
from .dice_loss import DiceLoss
